
#ifndef PRISON_EXPORT_H
#define PRISON_EXPORT_H

#ifdef PRISON_STATIC_DEFINE
#  define PRISON_EXPORT
#  define PRISON_NO_EXPORT
#else
#  ifndef PRISON_EXPORT
#    ifdef KF5Prison_EXPORTS
        /* We are building this library */
#      define PRISON_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define PRISON_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef PRISON_NO_EXPORT
#    define PRISON_NO_EXPORT 
#  endif
#endif

#ifndef PRISON_DEPRECATED
#  define PRISON_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef PRISON_DEPRECATED_EXPORT
#  define PRISON_DEPRECATED_EXPORT PRISON_EXPORT PRISON_DEPRECATED
#endif

#ifndef PRISON_DEPRECATED_NO_EXPORT
#  define PRISON_DEPRECATED_NO_EXPORT PRISON_NO_EXPORT PRISON_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef PRISON_NO_DEPRECATED
#    define PRISON_NO_DEPRECATED
#  endif
#endif

#endif
